==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE57S.sql <==
/****************************************************************************/
/* GE57 ( 雛形明細定義ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE57 (
   SYSTEM_ID        varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , LISTID           varchar (  10 )                 NOT NULL            /*  20 帳票ID       */
 , SHEETNO          INTEGER             DEFAULT 0   NOT NULL            /*  30 ｼｰﾄ番号      */
 , SHEETREF         varchar (  30 )                 NOT NULL            /*  40 対応ｼｰﾄ番号  */
 , HEADDBID         varchar (  20 )                                     /*  50 ﾍｯﾀﾞDBID     */
 , BODYDBID         varchar (  20 )                                     /*  60 ﾎﾞﾃﾞｨDBID    */
 , LOOPCLM          varchar (  30 )                                     /*  70 繰返必須ｶﾗﾑ  */
 , RELEASE_NOTES    varchar ( 120 )                                     /*  80 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar (  20 )                                     /*  90 設変番号     */
 , FGJ              varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar (  14 )                                     /* 820 登録日時     */
 , PGSET            varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET           varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET           varchar (  10 )                                     /* 850 作成者       */
 , DYUPD            varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD            varchar (  10 )                                     /* 870 更新PG       */
 , PGPUPD           varchar (  10 )                                     /* 880 更新親PG     */
 , USRUPD           varchar (  10 )                                     /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE57S.sql <==
/****************************************************************************/
/* GE57 ( 雛形明細ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE57 (
   SYSTEM_ID        varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , LISTID           varchar (  10 )                 NOT NULL            /*  20 帳票ID       */
 , SHEETNO          INTEGER             DEFAULT 0   NOT NULL            /*  30 ｼｰﾄ番号      */
 , SHEETREF         varchar (  30 )                 NOT NULL            /*  40 対応ｼｰﾄ番号  */
 , HEADDBID         varchar (  20 )                                     /*  50 ﾍｯﾀﾞDBID     */
 , BODYDBID         varchar (  20 )                                     /*  60 ﾎﾞﾃﾞｨDBID    */
 , LOOPCLM          varchar (  30 )                                     /*  70 繰返必須ｶﾗﾑ  */
 , RELEASE_NOTES    varchar ( 120 )                                     /*  80 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar (  20 )                                     /*  90 設変番号     */
 , FGJ              varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar (  14 )                                     /* 820 作成日時     */
 , PGSET            varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET           varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET           varchar (  10 )                                     /* 850 作成者       */
 , DYUPD            varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD            varchar (  10 )                                     /* 870 更新PG       */
 , PGPUPD           varchar (  10 )                                     /* 880 更新親PG     */
 , USRUPD           varchar (  10 )                                     /* 890 更新者       */
);
